// ************************************************
// *  Layout Analysis DLL 32 Bits functions       *
// *  Library Version 1.0                         *
// *  Copyright 2006 - All rigths reserved        *
// *  RECOGNIFORM TECHNOLGIES SPA                 *
// *  www.recogniform.com - info@recogniform.com  *
// ************************************************

unit recolaapi;

interface

Var

 //  Goal: nitialize the engine
 //  Requires: company name, license string
 //  Result: session handle
 LA_Init : function (Company,LicenseKey:PChar):Integer; stdcall;

 //  Goal: deinitialize the engine
 //  Requires: session handle
 //  Result: n/a
 LA_Done : procedure (SessionHandle:Integer); stdcall;

 //  Goal: performs the layout analysis
 //  Requires: session handle, dib handle
 //  Result: error code (0=success)
 LA_Execute : function (SessionHandle:Integer;DIBHandle:Integer):Integer; stdcall;

 //  Goal: returns the number of found zones
 //  Requires: session handle
 //  Result: number of zones found
 LA_GetZonesCount : function (SessionHandle:Integer):Integer; stdcall;

 //  Goal: retrieve the zone rect coordinates
 //  Requires: session handle, zone index, left, top, right, bottom coordinates buffer (output)
 //  Result: error code (0=success)
 LA_GetZoneRect : function (SessionHandle:Integer; ZoneIndex:Integer; Var Left:Integer; Var Top:Integer; Var Right:Integer; Var Bottom:Integer):Integer; stdcall;

 //  Goal: retrieve the zone content
 //  Requires: session handle, zone index, zone content type buffer (output)
 //  Result: error code (0=success)
 LA_GetZoneContent : function (SessionHandle:Integer;ZoneIndex:Integer;Var Content:Integer):Integer; stdcall;

 //  Goal: set custom parameters
 //  Requires: session handle, parameter index, parameter value
 //  Result: one if success, zero if some error occurred
 LA_SetParameter : function (SessionHandle:Integer; ParameterIndex:Integer; ParameterValue:Pointer):Integer; stdcall;

 //  Goal: set custom parameters
 //  Requires: session handle, parameter index, parameter value
 //  Result: one if success, zero if some error occurred
 LA_GetParameter : function (SessionHandle:Integer; ParameterIndex:Integer; ParameterValue:Pointer):Integer; stdcall;

 //  Goal: load dynamically the Layout Analysis library
 //  Requires: n/a
 //  Result: -1 if an error occurred, else 0
 function LoadLALibrary:Integer;

 //  Goal: unload the Layout Analysis library
 //  Requires: n/a
 //  Result: n/a
 procedure FreeLALibrary;

implementation

Uses Windows,Dialogs;

// LA Library handle
Var LALIB:THandle;

// Use this funciton to load dynamically the LA library
// The function return -1 if the library is not found or 0 if all goes rigth
function LoadLALibrary:Integer;
 begin
  Result:=0;
  if LALIB<>0 then Exit;
  LALIB:=LoadLibrary('RECOLA.DLL');
  if (LALIB=0) then
   begin
    ShowMessage('Unable to load RECOLA.DLL');
    Result:=-1;
   end
  else
   begin
    LA_Init:=GetProcAddress(LALIB,'LA_Init');
    LA_Done:=GetProcAddress(LALIB,'LA_Done');
    LA_Execute:=GetProcAddress(LALIB,'LA_Execute');
    LA_GetZonesCount:=GetProcAddress(LALIB,'LA_GetZonesCount');
    La_GetZoneRect:=GetProcAddress(LALIB,'LA_GetZoneRect');
    La_GetZoneContent:=GetProcAddress(LALIB,'LA_GetZoneContent');
    LA_SetParameter:=GetProcAddress(LALIB,'LA_SetParameter');
    LA_GetParameter:=GetProcAddress(LALIB,'LA_GetParameter');
    Result:=0;
   end;
 end;

// Use this funciton to unload the LA library when you don't need it
procedure FreeLALibrary;
 begin
  if (LALIB<>0) then
   begin
    FreeLibrary(LALIB);
    LALIB := 0;
   end;
 end;

begin
 LALIB:=0;
end.
